@@ -698,7 +698,7 @@ namespace Mistelix.Widgets
 		[GLib.ConnectBefore()]
 		void OnKeyPressed (object sender, Gtk.KeyPressEventArgs args)
 		{
-			if (args.Event.Key == Gdk.Key.Delete) {
+			if (args.Event.Key == Gdk.Key.Delete || args.Event.Key == Gdk.Key.KP_Delete) {
 				args.RetVal = true;
 				OnRemoveSelectedImage (sender, EventArgs.Empty);
 			}
