@@ -26,7 +26,6 @@ using Gtk;
 using Gdk;
 using Gnome;
 using System.Runtime.InteropServices;
-using System.Text;
 using System.Collections.Generic;
 using System.Diagnostics;
 using System.IO;
@@ -38,6 +37,7 @@ using Mistelix.Widgets;
 using Mistelix.Dialogs;
 using Mistelix.DataModel;
 using Mistelix.Core;
+using Mistelix.Backends.OS;
 
 namespace Mistelix
 {
@@ -117,11 +117,11 @@ namespace Mistelix
 			//element_view.LoadElements ();
 			//authoring_view.UpdateTheme ();
 
+			CreateViews ();
+
 			if (preferences.GetBoolValue (Preferences.SafeAreaKey) == true)
 				safearea_menuitem.Active = true;
 
-			CreateViews ();
-
 			recent_submenu = new ExtendedMenu ();
 			recent_menuitem.Submenu = recent_submenu;
 
@@ -201,9 +201,9 @@ namespace Mistelix
 			Mistelix gui = new Mistelix (args);
 
 			try {
-				SetProcessName (Defines.APPNAME_LOWER);
+				Backends.OS.Unix.SetProcessName (Defines.APPNAME_LOWER);
 			} catch (Exception) {
-				Logger.Error ("Mistelix.Main. Cannot set process");
+				Logger.Error ("Mistelix.Main. Cannot set process name");
 			}
 
 			gui.Run ();
@@ -616,30 +616,6 @@ namespace Mistelix
 			recent = (RecentFile) menu_item.Data;
 			OpenProject (recent.filename);
 		}
-
-		[DllImport ("libc")] // Linux
-		private static extern int prctl (int option, byte [] arg2, IntPtr arg3, IntPtr arg4, IntPtr arg5);
-
-		[DllImport ("libc")] // BSD
-		private static extern void setproctitle (byte [] fmt, byte [] str_arg);
-
-		public static void SetProcessName (string name)
-		{
-			int platform = (int) Environment.OSVersion.Platform;		
-			if (platform != 4 && platform != 128)
-				return;
-
-			try {
-				if (prctl (15 /* PR_SET_NAME */, Encoding.ASCII.GetBytes (name + "\0"),
-					IntPtr.Zero, IntPtr.Zero, IntPtr.Zero) != 0) {
-					throw new ApplicationException ("Error setting process name: " + 
-						Mono.Unix.Native.Stdlib.GetLastError ());
-				}
-			} catch (EntryPointNotFoundException) {
-				setproctitle (Encoding.ASCII.GetBytes ("%s\0"), 
-					Encoding.ASCII.GetBytes (name + "\0"));
-			}
-		}
 	}
 }
 
